#!/usr/bin/env python
# -*- coding: utf-8 -*-
# git filter-branch --tree-filter "rm -rf pyzipcode/allCountries.txt" HEAD
# git filter-branch -f  --index-filter "git rm --cached --ignore-unmatch pyzipcode/allCountries.txt"
# git filter-branch -f --index-filter "git rm --cached --ignore-unmatch fixtures/11_user_answer.json"
# GB is delivery is pending
import pandas as pd
from typing import Union
from pyworldpostal.country_files import (AD, AR, AS, AT, AU, AX, AZ, BD, BE, BG, BM, BR, BY, CA, CH, CL, CO, CR, CY, CZ, DE, DK, DO,
                           DZ, EE, ES, FI, FM, FO, FR, GF, GG, GL, GP, GT, GU, HR, HU, IE, IM, IN, IS, IT, JE, JP,
                           KR, LI, LK, LT, LU, LV, MC, MD, MH, MK, MP, MQ, MT, MW, MX, MY, NC, NL, NO, NZ, PE, PH, PK,
                           PL, PM, PR, PT, PW, RE, RO, RS, RU, SE, SG, SI, SJ, SK, SM, TH, TR, UA, US, UY,
                           VA, VI, WF, YT, ZA)

__version__ = "0.1.0"
__author__ = "Dalwinder singh"

val_counties = ["AD", "AR", "AS", "AT", "AU", "AX", "AZ", "BD", "BE", "BG", "BM", "BR", "BY", "CA", "CH", "CL", "CO",
                "CR", "CY", "CZ", "DE", "DK", "DO", "DZ", "EE", "ES", "FI", "FM", "FO", "FR", "GB", "GF", "GG", "GL",
                "GP", "GT", "GU", "HR", "HU", "IE", "IM", "IN", "IS", "IT", "JE", "JP", "KR", "LI", "LK", "LT", "LU",
                "LV", "MC", "MD", "MH", "MK", "MP", "MQ", "MT", "MW", "MX", "MY", "NC", "NL", "NO", "NZ", "PE", "PH",
                "PK", "PL", "PM", "postal_data", "PR", "PT", "PW", "RE", "RO", "RS", "RU", "SE", "SG",
                "SI", "SJ", "SK", "SM", "TH", "TR", "UA", "US", "UY", "VA", "VI", "WF", "YT", "ZA"]


class WorldPostalSearch(object):
    def valid_countries(self):
        return val_counties

    def bulkget(self, pin_contry: list):
        res = []
        for i in pin_contry:
            pincode, country_code = i[0], i[1]
            out = self._get(pincode, country_code)
            res.extend(out)
        return res

    def return_df(self, pincode, df):
        if isinstance(pincode, list):
            df = df[df["postal_code"].isin(pincode)]
        if isinstance(pincode, str):
            df = df[df["postal_code"].isin([pincode])]
        if df.empty:
            return [{}]
        else:
            df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2", "admin_name3",
                          "place_name"]
            return df.to_dict("records")

    def _get(self, pincode: Union[list, str], country: str):
        if country in val_counties:
            if country == "AD":
                df = pd.DataFrame(AD.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AR":
                df = pd.DataFrame(AR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AS":
                df = pd.DataFrame(AS.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AT":
                df = pd.DataFrame(AT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AU":
                df = pd.DataFrame(AU.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AX":
                df = pd.DataFrame(AX.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "AZ":
                df = pd.DataFrame(AZ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BD":
                df = pd.DataFrame(BD.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BE":
                df = pd.DataFrame(BE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BG":
                df = pd.DataFrame(BG.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BM":
                df = pd.DataFrame(BM.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BR":
                df = pd.DataFrame(BR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "BY":
                df = pd.DataFrame(BY.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CA":
                df = pd.DataFrame(CA.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CH":
                df = pd.DataFrame(CH.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CL":
                df = pd.DataFrame(CL.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CO":
                df = pd.DataFrame(CO.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CR":
                df = pd.DataFrame(CR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CY":
                df = pd.DataFrame(CY.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "CZ":
                df = pd.DataFrame(CZ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "DE":
                df = pd.DataFrame(DE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "DK":
                df = pd.DataFrame(DK.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "DO":
                df = pd.DataFrame(DO.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "DZ":
                df = pd.DataFrame(DZ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "EE":
                df = pd.DataFrame(EE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "ES":
                df = pd.DataFrame(ES.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "FI":

                df = pd.DataFrame(FI.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "FM":
                df = pd.DataFrame(FM.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "FO":
                df = pd.DataFrame(FO.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "FR":
                df = pd.DataFrame(FR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            # elif country == "GB":
            #     df = pd.DataFrame(GB.PostalData().data())
            #     if isinstance(pincode, list):
            #         df = df[df["postal_code"].isin(pincode)]
            #     if isinstance(pincode, str):
            #         df = df[df["postal_code"].isin([pincode])]
            #     if df.empty:
            #         return [{}]
            #     else:
            #         df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
            #                       "admin_name3", "place_name"]
            #         return df.to_dict("records")
            elif country == "GF":
                df = pd.DataFrame(GF.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "GG":
                df = pd.DataFrame(GG.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "GL":
                df = pd.DataFrame(GL.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "GP":
                df = pd.DataFrame(GP.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "GT":
                df = pd.DataFrame(GT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "GU":
                df = pd.DataFrame(GU.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "HR":
                df = pd.DataFrame(HR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "HU":
                df = pd.DataFrame(HU.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "IE":
                df = pd.DataFrame(IE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "IM":
                df = pd.DataFrame(IM.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "IN":
                df = pd.DataFrame(IN.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "IS":
                df = pd.DataFrame(IS.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "IT":
                df = pd.DataFrame(IT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "JE":
                df = pd.DataFrame(JE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "JP":
                df = pd.DataFrame(JP.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "KR":
                df = pd.DataFrame(KR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "LI":
                df = pd.DataFrame(LI.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "LK":
                df = pd.DataFrame(LK.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "LT":
                df = pd.DataFrame(LT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "LU":
                df = pd.DataFrame(LU.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "LV":
                df = pd.DataFrame(LV.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MC":
                df = pd.DataFrame(MC.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MD":
                df = pd.DataFrame(MD.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MH":
                df = pd.DataFrame(MH.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MK":
                df = pd.DataFrame(MK.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MP":
                df = pd.DataFrame(MP.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MQ":
                df = pd.DataFrame(MQ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MT":
                df = pd.DataFrame(MT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MW":
                df = pd.DataFrame(MW.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MX":
                df = pd.DataFrame(MX.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "MY":
                df = pd.DataFrame(MY.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "NC":
                df = pd.DataFrame(NC.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "NL":
                df = pd.DataFrame(NL.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "NO":
                df = pd.DataFrame(NO.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "NZ":
                df = pd.DataFrame(NZ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PE":
                df = pd.DataFrame(PE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PH":
                df = pd.DataFrame(PH.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PK":
                df = pd.DataFrame(PK.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PL":
                df = pd.DataFrame(PL.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PM":
                df = pd.DataFrame(PM.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PR":
                df = pd.DataFrame(PR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PT":
                df = pd.DataFrame(PT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "PW":
                df = pd.DataFrame(PW.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "RE":
                df = pd.DataFrame(RE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "RO":
                df = pd.DataFrame(RO.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "RS":
                df = pd.DataFrame(RS.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "RU":
                df = pd.DataFrame(RU.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SE":
                df = pd.DataFrame(SE.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SG":
                df = pd.DataFrame(SG.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SI":
                df = pd.DataFrame(SI.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SJ":
                df = pd.DataFrame(SJ.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SK":
                df = pd.DataFrame(SK.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "SM":
                df = pd.DataFrame(SM.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "TH":
                df = pd.DataFrame(TH.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "TR":
                df = pd.DataFrame(TR.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "UA":
                df = pd.DataFrame(UA.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "US":
                df = pd.DataFrame(US.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "UY":
                df = pd.DataFrame(UY.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "VA":
                df = pd.DataFrame(VA.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "VI":
                df = pd.DataFrame(VI.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "WF":
                df = pd.DataFrame(WF.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "YT":
                df = pd.DataFrame(YT.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            elif country == "ZA":
                df = pd.DataFrame(ZA.PostalData().data())
                if isinstance(pincode, list):
                    df = df[df["postal_code"].isin(pincode)]
                if isinstance(pincode, str):
                    df = df[df["postal_code"].isin([pincode])]
                if df.empty:
                    return [{}]
                else:
                    df.columns = ["postal_code", "country_code", "state_code", "state_name", "admin_name2",
                                  "admin_name3", "place_name"]
                    return df.to_dict("records")
            else:
                [{}]

#print(WorldPostalSearch().bulkget([("AD100", "AD"), ("AD1000", "AD"), ("AD100", "AD"), ("AD200", "AD")]))





import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96940", "country_code": "PW", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Palau"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "AD100", "country_code": "AD", "admin_code1": "02", "admin_name1": "Canillo", "admin_name2": null, "admin_name3": null, "place_name": "Canillo"}, {"postal_code": "AD200", "country_code": "AD", "admin_code1": "03", "admin_name1": "Encamp", "admin_name2": null, "admin_name3": null, "place_name": "Encamp"}, {"postal_code": "AD400", "country_code": "AD", "admin_code1": "04", "admin_name1": "La Massana", "admin_name2": null, "admin_name3": null, "place_name": "La Massana"}, {"postal_code": "AD300", "country_code": "AD", "admin_code1": "05", "admin_name1": "Ordino", "admin_name2": null, "admin_name3": null, "place_name": "Ordino"}, {"postal_code": "AD600", "country_code": "AD", "admin_code1": "06", "admin_name1": "Sant Juli\u00e0 de L\u00f2ria", "admin_name2": null, "admin_name3": null, "place_name": "Sant Juli\u00e0 de L\u00f2ria"}, {"postal_code": "AD500", "country_code": "AD", "admin_code1": "07", "admin_name1": "Andorra la Vella", "admin_name2": null, "admin_name3": null, "place_name": "Andorra la Vella"}, {"postal_code": "AD700", "country_code": "AD", "admin_code1": "08", "admin_name1": "Escaldes-Engordany", "admin_name2": null, "admin_name3": null, "place_name": "Escaldes-Engordany"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 120, "country_code": "VA", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Citta Del Vaticano"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "9490", "country_code": "LI", "admin_code1": "7001", "admin_name1": "Vaduz", "admin_name2": null, "admin_name3": null, "place_name": "Vaduz"}, {"postal_code": "9495", "country_code": "LI", "admin_code1": "7002", "admin_name1": "Triesen", "admin_name2": null, "admin_name3": null, "place_name": "Triesen"}, {"postal_code": "9496", "country_code": "LI", "admin_code1": "7003", "admin_name1": "Balzers", "admin_name2": null, "admin_name3": null, "place_name": "Balzers"}, {"postal_code": "9497", "country_code": "LI", "admin_code1": "7004", "admin_name1": "Triesenberg", "admin_name2": null, "admin_name3": null, "place_name": "Triesenberg"}, {"postal_code": "9494", "country_code": "LI", "admin_code1": "7005", "admin_name1": "Schaan", "admin_name2": null, "admin_name3": null, "place_name": "Schaan"}, {"postal_code": "9498", "country_code": "LI", "admin_code1": "7006", "admin_name1": "Planken", "admin_name2": null, "admin_name3": null, "place_name": "Planken"}, {"postal_code": "9485", "country_code": "LI", "admin_code1": "7007", "admin_name1": "Eschen", "admin_name2": null, "admin_name3": null, "place_name": "Nendeln"}, {"postal_code": "9492", "country_code": "LI", "admin_code1": "7007", "admin_name1": "Eschen", "admin_name2": null, "admin_name3": null, "place_name": "Eschen"}, {"postal_code": "9486", "country_code": "LI", "admin_code1": "7008", "admin_name1": "Mauren", "admin_name2": null, "admin_name3": null, "place_name": "Schaanwald"}, {"postal_code": "9493", "country_code": "LI", "admin_code1": "7008", "admin_name1": "Mauren", "admin_name2": null, "admin_name3": null, "place_name": "Mauren FL"}, {"postal_code": "9487", "country_code": "LI", "admin_code1": "7009", "admin_name1": "Gamprin", "admin_name2": null, "admin_name3": null, "place_name": "Gamprin-Bendern"}, {"postal_code": "9491", "country_code": "LI", "admin_code1": "7010", "admin_name1": "Ruggell", "admin_name2": null, "admin_name3": null, "place_name": "Ruggell"}, {"postal_code": "9488", "country_code": "LI", "admin_code1": "7011", "admin_name1": "Schellenberg", "admin_name2": null, "admin_name3": null, "place_name": "Schellenberg"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 97605, "country_code": "YT", "admin_code1": "00", "admin_name1": "Mayotte (general)", "admin_name2": null, "admin_name3": null, "place_name": "Passamainty"}, {"postal_code": 97630, "country_code": "YT", "admin_code1": "97601", "admin_name1": "Acoua", "admin_name2": null, "admin_name3": null, "place_name": "Acoua"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97602", "admin_name1": "Bandraboua", "admin_name2": null, "admin_name3": null, "place_name": "Bandraboua"}, {"postal_code": 97660, "country_code": "YT", "admin_code1": "97603", "admin_name1": "Bandrele", "admin_name2": null, "admin_name3": null, "place_name": "Bandr\u00e9l\u00e9"}, {"postal_code": 97620, "country_code": "YT", "admin_code1": "97604", "admin_name1": "Bou\u00e9ni", "admin_name2": null, "admin_name3": null, "place_name": "Bou\u00e9ni"}, {"postal_code": 97670, "country_code": "YT", "admin_code1": "97605", "admin_name1": "Chiconi", "admin_name2": null, "admin_name3": null, "place_name": "Chiconi"}, {"postal_code": 97620, "country_code": "YT", "admin_code1": "97606", "admin_name1": "Chirongui", "admin_name2": null, "admin_name3": null, "place_name": "Chirongui"}, {"postal_code": 97660, "country_code": "YT", "admin_code1": "97607", "admin_name1": "Dembeni", "admin_name2": null, "admin_name3": null, "place_name": "Dembeni"}, {"postal_code": 97615, "country_code": "YT", "admin_code1": "97608", "admin_name1": "Dzaoudzi", "admin_name2": null, "admin_name3": null, "place_name": "Dzaoudzi"}, {"postal_code": 97625, "country_code": "YT", "admin_code1": "97609", "admin_name1": "Kani-K\u00e9li", "admin_name2": null, "admin_name3": null, "place_name": "Kani K\u00e9li"}, {"postal_code": 97600, "country_code": "YT", "admin_code1": "97610", "admin_name1": "Koungou", "admin_name2": null, "admin_name3": null, "place_name": "Koungou"}, {"postal_code": 97600, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97605, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97680, "country_code": "YT", "admin_code1": "97611", "admin_name1": "Mamoudzou", "admin_name2": null, "admin_name3": null, "place_name": "Mamoudzou"}, {"postal_code": 97630, "country_code": "YT", "admin_code1": "97612", "admin_name1": "Mtsamboro", "admin_name2": null, "admin_name3": null, "place_name": "Mtsamboro"}, {"postal_code": 97650, "country_code": "YT", "admin_code1": "97613", "admin_name1": "MTsangamouji", "admin_name2": null, "admin_name3": null, "place_name": "MTsangamouji"}, {"postal_code": 97670, "country_code": "YT", "admin_code1": "97614", "admin_name1": "Ouangani", "admin_name2": null, "admin_name3": null, "place_name": "Ouangani"}, {"postal_code": 97615, "country_code": "YT", "admin_code1": "97615", "admin_name1": "Pamandzi", "admin_name2": null, "admin_name3": null, "place_name": "Pamandzi"}, {"postal_code": 97640, "country_code": "YT", "admin_code1": "97616", "admin_name1": "Sada", "admin_name2": null, "admin_name3": null, "place_name": "Sada"}, {"postal_code": 97680, "country_code": "YT", "admin_code1": "97617", "admin_name1": "Tsingoni", "admin_name2": null, "admin_name3": null, "place_name": "Tsingoni"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96799", "country_code": "AS", "admin_code1": null, "admin_name1": "As", "admin_name2": null, "admin_name3": null, "place_name": "Pago Pago"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 98610, "country_code": "WF", "admin_code1": "98611", "admin_name1": "Circonscription dAlo", "admin_name2": null, "admin_name3": null, "place_name": "Alo"}, {"postal_code": 98620, "country_code": "WF", "admin_code1": "98612", "admin_name1": "Circonscription de Sigave", "admin_name2": null, "admin_name3": null, "place_name": "Sigave"}, {"postal_code": 98600, "country_code": "WF", "admin_code1": "98613", "admin_name1": "Circonscription dUv\u00e9a", "admin_name2": null, "admin_name3": null, "place_name": "Uv\u00e9a"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96944", "country_code": "FM", "admin_code1": "01", "admin_name1": "State of Kosrae", "admin_name2": null, "admin_name3": null, "place_name": "Kosrae"}, {"postal_code": "96941", "country_code": "FM", "admin_code1": "02", "admin_name1": "State of Pohnpei", "admin_name2": null, "admin_name3": null, "place_name": "Pohnpei"}, {"postal_code": "96942", "country_code": "FM", "admin_code1": "03", "admin_name1": "State of Chuuk", "admin_name2": null, "admin_name3": null, "place_name": "Chuuk"}, {"postal_code": "96943", "country_code": "FM", "admin_code1": "04", "admin_name1": "State of Yap", "admin_name2": null, "admin_name3": null, "place_name": "Yap"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96960", "country_code": "MH", "admin_code1": "68", "admin_name1": "Marshall Islands", "admin_name2": "Ailinginae", "admin_name3": null, "place_name": "Majuro"}, {"postal_code": "96970", "country_code": "MH", "admin_code1": "68", "admin_name1": "Marshall Islands", "admin_name2": "Ailinginae", "admin_name3": null, "place_name": "Ebeye"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "96951", "country_code": "MP", "admin_code1": "100", "admin_name1": "Rota", "admin_name2": null, "admin_name3": null, "place_name": "Rota"}, {"postal_code": "96950", "country_code": "MP", "admin_code1": "110", "admin_name1": "Saipan", "admin_name2": null, "admin_name3": null, "place_name": "Saipan"}, {"postal_code": "96952", "country_code": "MP", "admin_code1": "120", "admin_name1": "Tinian", "admin_name2": null, "admin_name3": null, "place_name": "Tinian"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": 820, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 821, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 822, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 823, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 824, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Christiansted"}, {"postal_code": 840, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Frederiksted"}, {"postal_code": 841, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Frederiksted"}, {"postal_code": 850, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Kingshill"}, {"postal_code": 851, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Croix", "admin_name3": null, "place_name": "Kingshill"}, {"postal_code": 830, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. John", "admin_name3": null, "place_name": "St John"}, {"postal_code": 831, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. John", "admin_name3": null, "place_name": "St John"}, {"postal_code": 801, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 802, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 803, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 804, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}, {"postal_code": 805, "country_code": "VI", "admin_code1": "78", "admin_name1": "Vi", "admin_name2": "St. Thomas", "admin_name3": null, "place_name": "St Thomas"}]'



import json

class PostalData:
    def data(self):
            return json.loads(d)

d=r'[{"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "San Marino"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Casole"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Murata"}, {"postal_code": "47890", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Santa Mustiola"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Galazzano"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Falciano"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Dogana"}, {"postal_code": "47891", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Rovereta"}, {"postal_code": "47892", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Acquaviva"}, {"postal_code": "47892", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Gualdicciolo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Ventoso"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Valdragone"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "San Giovanni"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Cailungo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Ca Rigo"}, {"postal_code": "47893", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Borgo Maggiore"}, {"postal_code": "47894", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Teglio"}, {"postal_code": "47894", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Chiesanuova"}, {"postal_code": "47895", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Torraccia"}, {"postal_code": "47895", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Domagnano"}, {"postal_code": "47896", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Faetano"}, {"postal_code": "47897", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Fiorentino"}, {"postal_code": "47898", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Montegiardino"}, {"postal_code": "47898", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Cerbaiola"}, {"postal_code": "47899", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Serravalle"}, {"postal_code": "47899", "country_code": "SM", "admin_code1": null, "admin_name1": null, "admin_name2": null, "admin_name3": null, "place_name": "Fiorina"}]'